@@ -39,6 +39,14 @@ cobib search Einstein -- ++year 2020
 Note, that we use the auxiliary `--` argument to separate the filters from the actual arguments.
 While this is not strictly necessary it helps to disambiguate the origin of the arguments.
 
+.. note::
+
+   You may also pass other arguments to the `list` command such as `--sort <field>`, `--reverse`, or
+   `--limit`. However, these affect which list of entries is being searched over and not the search
+   results directly. Thus, the `--limit` will provide an upper bound on the number of entries that
+   is being searched and does _not_ indicate the maximum number of search results (since this can
+   still be lower).
+
 ### Associated files
 
 The search will also be performed on any associated files of your entries.
@@ -59,21 +67,20 @@ By default, it is bound to the `/` key.
 from __future__ import annotations
 
 import argparse
+import asyncio
 import logging
 
-from rich.console import Console, ConsoleRenderable
-from rich.prompt import PromptBase, PromptType
+from rich.console import ConsoleRenderable
 from rich.text import Text
 from rich.tree import Tree
-from textual.app import App
 from typing_extensions import override
 
-from cobib import __version__
 from cobib.config import Event, config
 from cobib.database import Entry
 from cobib.ui.components import SearchView
+from cobib.utils.progress import Progress
 
-from .base_command import ArgumentParser, Command
+from .base_command import Command
 from .list_ import ListCommand
 
 LOGGER = logging.getLogger(__name__)
@@ -104,13 +111,8 @@ class SearchCommand(Command):
     name = "search"
 
     @override
-    def __init__(
-        self,
-        *args: str,
-        console: Console | App[None] | None = None,
-        prompt: type[PromptBase[PromptType]] | None = None,
-    ) -> None:
-        super().__init__(*args, console=console, prompt=prompt)
+    def __init__(self, *args: str) -> None:
+        super().__init__(*args)
 
         self.entries: list[Entry] = []
         """A filtered list of entries searched over by this command."""
@@ -127,7 +129,9 @@ class SearchCommand(Command):
     @override
     @classmethod
     def init_argparser(cls) -> None:
-        parser = ArgumentParser(prog="search", description="Search subcommand parser.")
+        parser = argparse.ArgumentParser(
+            prog="search", description="Search subcommand parser.", exit_on_error=True
+        )
         parser.add_argument("query", type=str, nargs="+", help="text to search for")
         ignore_case_group = parser.add_mutually_exclusive_group()
         ignore_case_group.add_argument(
@@ -162,7 +166,7 @@ class SearchCommand(Command):
             "filter",
             nargs="*",
             help="You can specify filters as used by the `list` command in order to select a "
-            "subset of labels to be modified. To ensure this works as expected you should add the "
+            "subset of labels to be searched. To ensure this works as expected you should add the "
             "pseudo-argument '--' before the list of filters. See also `list --help` for more "
             "information.",
         )
@@ -188,19 +192,29 @@ class SearchCommand(Command):
         return largs
 
     @override
-    def execute(self) -> None:
+    async def execute(self) -> None:  # type: ignore[override]
         LOGGER.debug("Starting Search command.")
 
         Event.PreSearchCommand.fire(self)
 
-        self.entries, _ = ListCommand(*self.largs.filter).filter_entries()
+        self.entries, _ = ListCommand(*self.largs.filter).execute_dull()
 
         ignore_case = config.commands.search.ignore_case
         if self.largs.ignore_case is not None:
             ignore_case = self.largs.ignore_case
         LOGGER.debug("The search will be performed case %ssensitive", "in" if ignore_case else "")
 
+        progress_bar = Progress.initialize()
+        optional_awaitable = progress_bar.start()  # type: ignore[func-returns-value]
+        if optional_awaitable is not None:
+            await optional_awaitable
+
+        task = progress_bar.add_task("Searching...", total=len(self.entries))
+
         for entry in self.entries.copy():
+            progress_bar.advance(task, 1)
+            await asyncio.sleep(0)
+
             matches = entry.search(
                 self.largs.query, self.largs.context, ignore_case, self.largs.skip_files
             )
@@ -213,6 +227,8 @@ class SearchCommand(Command):
 
             LOGGER.debug('Entry "%s" includes %d hits.', entry.label, len(matches))
 
+        progress_bar.stop()
+
         Event.PostSearchCommand.fire(self)
 
     @override
@@ -264,20 +280,21 @@ class SearchCommand(Command):
 
         tree = SearchView(".")
         for entry, matches in zip(self.entries, self.matches):
+            data = entry.label
             subtree = tree.root.add(
                 Text.from_markup(
                     f"[search.label]{entry.markup_label()}[/search.label] - {len(matches)} match"
                     + ("es" if len(matches) > 1 else "")
                 ),
-                # TODO: make configurable
-                expand=False,
+                data=data,
+                expand=not config.tui.tree_folding[0],
             )
 
             for idx, match in enumerate(matches):
                 matchtree = subtree.add(
                     str(idx + 1),
-                    # TODO: make configurable
-                    expand=True,
+                    data=data,
+                    expand=not config.tui.tree_folding[1],
                 )
                 for line in match:
                     line_text = Text(line)
@@ -286,6 +303,6 @@ class SearchCommand(Command):
                         config.theme.search.query,
                         case_sensitive=not ignore_case,
                     )
-                    matchtree.add_leaf(line_text)
+                    matchtree.add_leaf(line_text, data=data)
 
         return tree
