@@ -1,4 +1,3 @@
-# pylint: disable=unnecessary-lambda,missing-docstring
 """coBib's configuration.
 
 This file contains both, the actual implementation of the `Config` classes, as well as the runtime
@@ -6,6 +5,7 @@ This file contains both, the actual implementation of the `Config` classes, as w
 Note, that this last link will not point to the correct location in the online documentation due to
 the nature of the lower-level import.
 """
+# ruff: noqa: E731, RUF009
 
 from __future__ import annotations
 
@@ -17,9 +17,9 @@ import sys
 from abc import abstractmethod
 from collections.abc import Callable
 from dataclasses import MISSING, dataclass, field, fields
-from enum import Enum, EnumMeta, auto
+from enum import Enum, auto
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, NamedTuple, TextIO
+from typing import TYPE_CHECKING, NamedTuple, TextIO
 
 from rich.style import Style
 from rich.theme import Theme
@@ -28,6 +28,8 @@ from typing_extensions import override
 from cobib.utils.rel_path import RelPath
 
 if TYPE_CHECKING:
+    import rich
+
     from .event import Event
 
 LOGGER = logging.getLogger(__name__)
@@ -62,7 +64,6 @@ class _ConfigBase:
 
     def defaults(self) -> None:
         """Resets the configuration to the default settings."""
-        # pylint: disable=no-member
         for name, field_ in self.__dataclass_fields__.items():
             if field_.default != MISSING:
                 setattr(self, name, field_.default)
@@ -76,9 +77,9 @@ class TagMarkup(NamedTuple):
     weight: int
     """The weight of the tag. This integer is used to determine the markup priority of the tag.
     Higher integer values indicate a higher priority."""
-    style: str | Style
-    """The style of the tag. This can be a `rich.Style` or a string which can be interpreted by
-    `rich.Style.parse`."""
+    style: str | rich.style.Style
+    """The style of the tag. This can be a `rich.style.Style` or a string which can be interpreted
+    by `rich.style.Style.parse`."""
 
 
 @dataclass
@@ -509,42 +510,136 @@ class CommandConfig(_ConfigBase):
         self.show.validate()
 
 
-class _DeprecateOnAccess(EnumMeta):
-    """A metaclass to add deprecation warnings to deprecated Enum values upon access."""
-
-    @override
-    def __getattribute__(cls, name: str) -> Any:
-        if name == "CAPTIAL":
-            LOGGER.log(
-                45,
-                "The LabelSuffix.CAPTIAL value is deprecated! Please switch to the correctly "
-                "spelled LabelSuffix.CAPITAL instead.",
-            )
-        return super().__getattribute__(name)
-
-    @override
-    def __getitem__(cls, name: str) -> Any:
-        if name == "CAPTIAL":
-            LOGGER.log(
-                45,
-                "The LabelSuffix.CAPTIAL value is deprecated! Please switch to the correctly "
-                "spelled LabelSuffix.CAPITAL instead.",
-            )
-        return super().__getitem__(name)
-
-
-class LabelSuffix(Enum, metaclass=_DeprecateOnAccess):
+class LabelSuffix(Enum):
     """Suffixes to disambiguate `cobib.database.Entry` labels."""
 
-    ALPHA = lambda count: chr(96 + count)  # pylint: disable=unnecessary-lambda-assignment
+    ALPHA = lambda count: chr(96 + count)
     """Enumerates with lowercase roman letters: `a-z`."""
-    CAPITAL = lambda count: chr(64 + count)  # pylint: disable=unnecessary-lambda-assignment
+    CAPITAL = lambda count: chr(64 + count)
     """Enumerates with uppercase roman letters: `A-Z`."""
-    # pylint: disable=unnecessary-lambda,unnecessary-lambda-assignment
+
     NUMERIC = lambda count: str(count)
     """Enumerates with arabic numbers: `1, 2, ...`."""
-    CAPTIAL = lambda count: chr(64 + count)  # pylint: disable=unnecessary-lambda-assignment
-    """**Deprecated!** This is a deprecated mistyped name of `LabelSuffix.CAPITAL`."""
+
+    @staticmethod
+    def reverse(type_: LabelSuffix, suffix: str) -> int:
+        """Reverses a label suffix enumerator from a suffix to its integer value.
+
+        Args:
+            type_: the `LabelSuffix` enumerator.
+            suffix: the suffix to reverse.
+
+        Returns:
+            The integer value of the reversed suffix.
+
+        Raises:
+            ValueError: if a non-numeric suffix is longer than 1 character.
+            ValueError: if an alphabetic suffix did not fall within the alphabet.
+            ValueError: if an invalid suffix of some other form is provided.
+        """
+        # TODO: once Python 3.10 becomes the default, change this to a match statement
+
+        if type_ == LabelSuffix.NUMERIC:
+            return int(suffix)
+
+        if len(suffix) > 1:
+            raise ValueError("A non-numeric suffix may not be longer than a single character.")
+
+        if type_ in {LabelSuffix.ALPHA, LabelSuffix.CAPITAL}:
+            # we can convert both of these cases in the same way by using base 36 for `int()`
+            ret = int(suffix, 36) - 9
+            if ret < 0:
+                raise ValueError(
+                    f"'{suffix}' is not a valid alphabetic suffix because its ANSI value falls "
+                    "outside of the alphabetic range, yielding a negative value."
+                )
+            return ret
+
+        raise ValueError(f"'{suffix}' is not a valid suffix.")
+
+    @staticmethod
+    def suffix_type(suffix: str) -> LabelSuffix | None:
+        """Determines the enumerator type for a given suffix.
+
+        Args:
+            suffix: the suffix whose enumerator type to determine.
+
+        Returns:
+            An optional enumerator type. If the suffix was invalid, `None` will be returned.
+        """
+        if not suffix.isascii():
+            # if the input contains a non-ASCII character, it cannot be a label suffix
+            return None
+
+        try:
+            # test if the suffix is numeric by attempting to convert it to a base-10 integer
+            _ = int(suffix)
+        except ValueError:
+            # first ensure that we have only alphabetic characters left
+            if not suffix.isalpha():
+                # this is important, because for example "hello123" will pass `islower()` because
+                # all of the cased characters are indeed lower-cased
+                return None
+
+            if suffix.islower():
+                return LabelSuffix.ALPHA
+            if suffix.isupper():
+                return LabelSuffix.CAPITAL
+        else:
+            return LabelSuffix.NUMERIC
+
+        # the provided suffix did not match any of the builtin enumerators
+        return None
+
+    @staticmethod
+    def trim_label(label: str, separator: str, type_: LabelSuffix) -> tuple[str, int]:
+        """Trims the provided label based on the separator and suffix type.
+
+        Args:
+            label: the label whose suffix to trim.
+            separator: the separator character between the actual label and the suffix.
+            type_: the `LabelSuffix` enumerator.
+
+        Returns:
+            The pair of the trimmed label and numeric value of its original suffix.
+        """
+        # initialize the counter of the suffix
+        suffix_value = 0
+
+        # try split the suffix from the label using the provided separator
+        if separator:
+            *pieces, suffix = label.split(separator)
+        else:
+            # no character is used for separation, we simply fall back to using the last one
+            suffix = label[-1]
+            pieces = [label[:-1]]
+
+        if pieces:
+            # piece together the left-over raw label without its suffix
+            raw_label = separator.join(pieces)
+            # determine the suffix type of this label
+            suffix_type = LabelSuffix.suffix_type(suffix)
+
+            if suffix_type is not None and suffix_type != type_:
+                # if it does not match the expected suffix type, ignore it
+                LOGGER.info(
+                    f"The suffix type encountered on '{label}' does not match the configured one. "
+                    "Assuming that this is intentional and therefore ignoring this as a suffix."
+                )
+                raw_label = label
+            else:
+                try:
+                    # try to obtain the suffix value by reversing it
+                    suffix_value = LabelSuffix.reverse(type_, suffix)
+                except ValueError:
+                    # if this fails, reset the raw label and assume that this was not an actual
+                    # disambiguation suffix
+                    raw_label = label
+        else:
+            # the original split did not yield any pieces so the `suffix` is the actual `raw_label`
+            raw_label = suffix
+
+        return (raw_label, suffix_value)
 
 
 class AuthorFormat(Enum):
@@ -570,7 +665,7 @@ class DatabaseFormatConfig(_ConfigBase):
     of the `cobib.commands.modify.ModifyCommand`). The default configuration value passes the
     originally provided label through [text-unidecode](https://pypi.org/project/text-unidecode/)
     which replaces all Unicode symbols with pure ASCII ones. A more useful example is
-    `"{unidecode(author[0]last)}{year}"` which takes the surname of the first author, replaces the
+    `"{unidecode(author[0].last)}{year}"` which takes the surname of the first author, replaces the
     Unicode characters and then immediately appends the publication year."""
     label_suffix: tuple[str, LabelSuffix] = field(default_factory=lambda: ("_", LabelSuffix.ALPHA))
     """Specifies the suffix format which is used to disambiguate labels if a conflict would occur.
@@ -601,7 +696,7 @@ class DatabaseFormatConfig(_ConfigBase):
             "config.database.format.label_default should be a string.",
         )
         self._assert(
-            isinstance(self.label_suffix, tuple) and len(self.label_suffix) == 2,
+            isinstance(self.label_suffix, tuple) and len(self.label_suffix) == 2,  # noqa: PLR2004
             "config.database.format.label_suffix should be a tuple of length 2.",
         )
         self._assert(
@@ -677,6 +772,9 @@ class DatabaseConfig(_ConfigBase):
     file: str | Path = "~/.local/share/cobib/literature.yaml"
     """Specifies the path to the database YAML file. You can use `~` to represent your `$HOME`
     directory."""
+    cache: str | Path | None = "~/.cache/cobib/databases/"
+    """Specifies the folder in which already parsed databases should be stored. Set this to `None`
+    if you want to disable caching entirely."""
     format: DatabaseFormatConfig = field(default_factory=lambda: DatabaseFormatConfig())
     """The nested section for database formatting settings."""
     git: bool = False
@@ -694,6 +792,10 @@ class DatabaseConfig(_ConfigBase):
     def validate(self) -> None:
         LOGGER.debug("Validating the DATABASE configuration section.")
         self._assert(isinstance(self.file, str), "config.database.file should be a string.")
+        self._assert(
+            self.cache is None or isinstance(self.cache, str),
+            "config.database.cache should be a string or `None`.",
+        )
         self._assert(isinstance(self.git, bool), "config.database.git should be a boolean.")
         self.format.validate()
         self.stringify.validate()
@@ -760,6 +862,11 @@ class TUIConfig(_ConfigBase):
     scroll_offset: int = 2
     """The minimum number of lines to keep above and below the cursor in the
     `cobib.ui.tui.components.ListView`. This is similar to Vim's `scrolloff` setting."""
+    tree_folding: tuple[bool, bool] = (True, False)
+    """The default folding level of the tree nodes in the `cobib.ui.tui.components.SearchView`. When
+    `True`, the node will be initialized to be folded (or collapsed), when `False`, it will be
+    expanded. The first boolean corresponds to the nodes for each matching entry, the second one is
+    for all the search matches."""
     preset_filters: list[str] = field(default_factory=list)
     """Permits providing a list of preset filters. These can be interactively selected in the TUI by
     pressing `p`. To specify these, simply provide a string with the filter arguments, for example:
@@ -902,7 +1009,6 @@ class Config(_ConfigBase):
     utils: UtilsConfig = field(default_factory=lambda: UtilsConfig())
     """The nested section for the utils settings."""
 
-    # pylint: disable=invalid-name
     XDG_CONFIG_FILE: str | Path = field(
         default="~/.config/cobib/config.py", init=False, repr=False, compare=False
     )
@@ -965,7 +1071,7 @@ class Config(_ConfigBase):
             sys.exit(1)
         else:
             cfg = importlib.util.module_from_spec(spec)
-            spec.loader.exec_module(cfg)  # type: ignore
+            spec.loader.exec_module(cfg)  # type: ignore[union-attr]
 
         try:
             # validate config
