@@ -4,10 +4,19 @@
 
 There are various kinds of event types:
     - Pre*Command: these fire before a command gets executed. Hooks subscribing to these events
-      are passed the argument dictionary which they can modify to their desire.
+      are passed an instance of the command which will be populated with the original command-line
+      arguments as well as the resulting `argparse.Namespace`.
     - Post*Command: these fire after a command got executed but (generally) **before** the
       Database gets written to file, allowing final touch-ups and modifications to take place.
-      The inputs to these hooks depend on the specific command firing the event (see below).
+      Just like the `Pre*Command` events, the input will be an instance of the command through which
+      a user can modify the command data at runtime.
+    - Pre*Import: these fire before an importer gets executed. Hooks subscribing to these events
+      are passed an instance of the importer which will be populated with the original command-line
+      arguments as well as the resulting `argparse.Namespace`.
+    - Post*Import: these fire after an importer got executed but (generally) **before** the
+      Database gets written to file, allowing final touch-ups and modifications to take place.
+      Just like the `Pre*Import` events, the input will be an instance of the importer through which
+      a user can modify the command data at runtime.
     - Pre*Parse: just like the Pre-Command events, these fire before a parser runs. As an input
       they generally get the driver input.
     - Post*Parse: these fire after a parser ran. They again allow final touch-ups of the
@@ -16,6 +25,8 @@ There are various kinds of event types:
       its desire. Changes will not become persistent in the Database.
     - Post*Dump: these fire after an entry got formatted as a string. The string can be
       post-processed with some final touch-ups.
+    - and finally there a few specific events not belonging to any of the categories mentioned
+      above, examples of which are the `PreGitCommit` and `PostGitCommit` events.
 
 All events are listed below.
 
@@ -24,17 +35,21 @@ All events are listed below.
 You can register a function to be executed when a certain event gets triggered as shown in the
 following example:
 ```python
-from pathlib import Path
 from os import system
 from cobib.config import Event
+from cobib.commands import InitCommand
 
 @Event.PostInitCommand.subscribe
-def add_remote(root: Path, file: Path) -> None:
-    system(f"git -C {root} remote add origin https://github.com/user/repo")
+def add_remote(cmd: InitCommand) -> None:
+    system(f"git -C {cmd.root} remote add origin https://github.com/user/repo")
 ```
 The above example gets run after the `init` command has finished. It adds a remote to the git
 repository. This can be useful in combination with automatic pushing to the remote like done here:
 ```python
+from pathlib import Path
+from os import system
+from cobib.config import Event
+
 @Event.PostGitCommit.subscribe
 def push_to_remote(root: Path, file: Path) -> None:
     system(f"git -C {root} push origin master")
@@ -55,45 +70,53 @@ from cobib.database import Entry
 def print_new_entries(bib: Dict[str, Entry) -> None:
     print("New entries being added: ", list(bib.keys()))
 ```
+
+You can find some useful examples on
+[this wiki page](https://gitlab.com/cobib/cobib/-/wikis/Useful-Event-Hooks).
 """
 
 from __future__ import annotations
 
 import logging
-from argparse import Namespace
 from enum import Enum
 from itertools import zip_longest
 from pathlib import Path
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Callable,
-    Dict,
-    ForwardRef,
-    List,
-    Optional,
-    Set,
-    Tuple,
-    get_type_hints,
-)
+from typing import TYPE_CHECKING, Any, Callable, Dict, ForwardRef, Optional, Tuple, get_type_hints
 
 from cobib.utils.rel_path import RelPath
 
 from .config import config
 
-_FORWARD_REFS: Dict[str, str] = {}
+_FORWARD_REFS: dict[str, str] = {}
 if TYPE_CHECKING:
+    from cobib import commands, importers
     from cobib.database import Entry
 else:
     _FORWARD_REFS = {
         "ForwardRef('Entry')": "Entry",
+        "ForwardRef('commands.AddCommand')": "cobib.commands.add.AddCommand",
+        "ForwardRef('commands.DeleteCommand')": "cobib.commands.delete.DeleteCommand",
+        "ForwardRef('commands.EditCommand')": "cobib.commands.edit.EditCommand",
+        "ForwardRef('commands.ExportCommand')": "cobib.commands.export.ExportCommand",
+        "ForwardRef('commands.GitCommand')": "cobib.commands.git.GitCommand",
+        "ForwardRef('commands.ImportCommand')": "cobib.commands.import_.ImportCommand",
+        "ForwardRef('commands.InitCommand')": "cobib.commands.init.InitCommand",
+        "ForwardRef('commands.ListCommand')": "cobib.commands.list_.ListCommand",
+        "ForwardRef('commands.ModifyCommand')": "cobib.commands.modify.ModifyCommand",
+        "ForwardRef('commands.OpenCommand')": "cobib.commands.open.OpenCommand",
+        "ForwardRef('commands.RedoCommand')": "cobib.commands.redo.RedoCommand",
+        "ForwardRef('commands.ReviewCommand')": "cobib.commands.review.ReviewCommand",
+        "ForwardRef('commands.SearchCommand')": "cobib.commands.search.SearchCommand",
+        "ForwardRef('commands.ShowCommand')": "cobib.commands.show.ShowCommand",
+        "ForwardRef('commands.UndoCommand')": "cobib.commands.undo.UndoCommand",
+        "ForwardRef('importers.ZoteroImporter')": "cobib.importers.zotero.ZoteroImporter",
     }
 
 LOGGER = logging.getLogger(__name__)
+"""@private module logger."""
 
 
 class Event(Enum):
-    # pylint: disable=invalid-name
     """Subscribable events triggered at runtime.
 
     The following sections list all events available in coBib. The heading of each section includes
@@ -121,308 +144,355 @@ class Event(Enum):
         obj = object.__new__(cls)
         obj._value_ = (value, annotation)
         obj._annotation_ = annotation
-        return obj  # type: ignore[no-any-return]
+        return obj
 
-    PreAddCommand: Event = Callable[[Namespace], None]  # type: ignore[assignment]
+    PreAddCommand: Event = Callable[["commands.AddCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before starting the `cobib.commands.add.AddCommand`.
 
     Arguments:
-        - `largs`: the `Namespace` dictionary of command arguments.
+        - `cobib.commands.add.AddCommand`: the command instance that is about to run.
 
     Returns:
-        Nothing. But the `Namespace` can be modified, affecting the command execution.
+        Nothing. But the command attributes can be modified, affecting the execution.
     """
-    PostAddCommand: Event = Callable[[Dict[str, "Entry"]], None]  # type: ignore[assignment]
+    PostAddCommand: Event = Callable[["commands.AddCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before finishing the `cobib.commands.add.AddCommand`.
 
     Arguments:
-        - `new_entries`: the dictionary of new entries to be added to the database.
+        - `cobib.commands.add.AddCommand`: the command instance that just ran.
 
     Returns:
-        Nothing. But the dictionary of new entries can be modified before the changes are made
-        persistent in the database.
+        Nothing. But the command attributes can be modified, affecting the execution.
 
     Note:
         This event fires *before* starting the `cobib.commands.edit.EditCommand` which starts if
         manual entry addition is requested.
     """
 
-    PreDeleteCommand: Event = Callable[[Namespace], None]  # type: ignore[assignment]
+    PreDeleteCommand: Event = Callable[["commands.DeleteCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before starting the `cobib.commands.delete.DeleteCommand`.
 
     Arguments:
-        - `largs`: the `Namespace` dictionary of command arguments.
+        - `cobib.commands.delete.DeleteCommand`: the command instance that is about to run.
 
     Returns:
-        Nothing. But the `Namespace` can be modified, affecting the command execution.
+        Nothing. But the command attributes can be modified, affecting the execution.
     """
-    PostDeleteCommand: Event = Callable[[Set[str]], None]  # type: ignore[assignment]
-    """Gets fired before finishing the `cobib.commands.DeleteCommand`. The deleted entry labels are
-    provided as input. Modifying them has no effect."""
+    PostDeleteCommand: Event = Callable[["commands.DeleteCommand"], None]  # type: ignore[assignment]
+    """
+    Fires:
+        Before finishing the `cobib.commands.delete.DeleteCommand`.
 
-    PreEditCommand: Event = Callable[[Namespace], None]  # type: ignore[assignment]
+    Arguments:
+        - `cobib.commands.delete.DeleteCommand`: the command instance that just ran.
+
+    Returns:
+        Nothing. While the deleted entry labels are accessible, modifying them has no effect.
+    """
+
+    PreEditCommand: Event = Callable[["commands.EditCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before starting the `cobib.commands.edit.EditCommand`.
 
     Arguments:
-        - `largs`: the `Namespace` dictionary of command arguments.
+        - `cobib.commands.edit.EditCommand`: the command instance that is about to run.
 
     Returns:
-        Nothing. But the `Namespace` can be modified, affecting the command execution.
+        Nothing. But the command attributes can be modified, affecting the execution.
     """
-    PostEditCommand: Event = Callable[["Entry"], None]  # type: ignore[assignment]
-    """Gets fired before finishing the `cobib.commands.EditCommand`. The new entry gets provided as
-    input and it may be modified. However, renaming the label will no longer be possible."""
+    PostEditCommand: Event = Callable[["commands.EditCommand"], None]  # type: ignore[assignment]
+    """
+    Fires:
+        Before finishing the `cobib.commands.edit.EditCommand`.
 
-    PreExportCommand: Event = Callable[[Namespace], None]  # type: ignore[assignment]
+    Arguments:
+        - `cobib.commands.edit.EditCommand`: the command instance that just ran.
+
+    Returns:
+        Nothing. While the edited entry is accessible, modifying it has no effect.
+    """
+
+    PreExportCommand: Event = Callable[["commands.ExportCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before starting the `cobib.commands.export.ExportCommand`.
 
     Arguments:
-        - `largs`: the `Namespace` dictionary of command arguments.
+        - `cobib.commands.export.ExportCommand`: the command instance that is about to run.
 
     Returns:
-        Nothing. But the `Namespace` can be modified, affecting the command execution.
+        Nothing. But the command attributes can be modified, affecting the execution.
     """
-    PostExportCommand: Event = Callable[[List[str], Namespace], None]  # type: ignore[assignment]
+    PostExportCommand: Event = Callable[["commands.ExportCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before finishing the `cobib.commands.export.ExportCommand`.
 
     Arguments:
-        - `labels`: the list of exported labels.
-        - `largs`: the `Namespace` dictionary of command arguments.
+        - `cobib.commands.export.ExportCommand`: the command instance that just ran.
+
+    Returns:
+        Nothing. The files to which has been exported are still accessible and open.
+    """
+
+    PreGitCommand: Event = Callable[["commands.GitCommand"], None]  # type: ignore[assignment]
+    """
+    Fires:
+        Before starting the `cobib.commands.git.GitCommand`.
+
+    Arguments:
+        - `cobib.commands.git.GitCommand`: the command instance that is about to run.
+
+    Returns:
+        Nothing. But the command attributes can be modified, affecting the execution.
+    """
+    PostGitCommand: Event = Callable[["commands.GitCommand"], None]  # type: ignore[assignment]
+    """
+    Fires:
+        Before finishing the `cobib.commands.git.GitCommand`.
+
+    Arguments:
+        - `cobib.commands.git.GitCommand`: the command instance that just ran.
 
     Returns:
         Nothing.
-
-    Note:
-        If exporting to a zip file, it will only be closed *after* this event got fired.
     """
 
-    PreImportCommand: Event = Callable[[Namespace], None]  # type: ignore[assignment]
+    PreImportCommand: Event = Callable[["commands.ImportCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before starting the `cobib.commands.import_.ImportCommand`.
 
     Arguments:
-        - `largs`: the `Namespace` dictionary of command arguments.
+        - `cobib.commands.import_.ImportCommand`: the command instance that is about to run.
 
     Returns:
-        Nothing. But the `Namespace` can be modified, affecting the command execution.
+        Nothing. But the command attributes can be modified, affecting the execution.
     """
-    PostImportCommand: Event = Callable[[Dict[str, "Entry"]], None]  # type: ignore[assignment]
+    PostImportCommand: Event = Callable[["commands.ImportCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before finishing the `cobib.commands.import_.ImportCommand`.
 
     Arguments:
-        - `new_entries`: the dictionary of new entries to be imported into the database.
+        - `cobib.commands.import_.ImportCommand`: the command instance that just ran.
 
     Returns:
         Nothing. But the dictionary of new entries can be modified before the changes are made
         persistent in the database.
     """
 
-    PreInitCommand: Event = Callable[[Namespace], None]  # type: ignore[assignment]
+    PreInitCommand: Event = Callable[["commands.InitCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before starting the `cobib.commands.init.InitCommand`.
 
     Arguments:
-        - `largs`: the `Namespace` dictionary of command arguments.
+        - `cobib.commands.init.InitCommand`: the command instance that is about to run.
 
     Returns:
-        Nothing. But the `Namespace` can be modified, affecting the command execution.
+        Nothing. But the command attributes can be modified, affecting the execution.
     """
-    PostInitCommand: Event = Callable[[Path, Path], None]  # type: ignore[assignment]
+    PostInitCommand: Event = Callable[["commands.InitCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before finishing the `cobib.commands.init.InitCommand`.
 
     Arguments:
-        - `root`: the `Path` to the root directory where the database file resides.
-        - `file`: the `Path` to the database file.
+        - `cobib.commands.init.InitCommand`: the command instance that just ran.
 
     Returns:
         Nothing.
     """
 
-    PreListCommand: Event = Callable[[Namespace], None]  # type: ignore[assignment]
+    PreListCommand: Event = Callable[["commands.ListCommand"], None]  # type: ignore[assignment]
     """
     Fires:
-        Before starting the `cobib.commands.list.ListCommand`.
+        Before starting the `cobib.commands.list_.ListCommand`.
 
     Arguments:
-        - `largs`: the `Namespace` dictionary of command arguments.
+        - `cobib.commands.list_.ListCommand`: the command instance that is about to run.
 
     Returns:
-        Nothing. But the `Namespace` can be modified, affecting the command execution.
+        Nothing. But the command attributes can be modified, affecting the execution.
     """
-    PostListCommand: Event = Callable[[List[str]], None]  # type: ignore[assignment]
+    PostListCommand: Event = Callable[["commands.ListCommand"], None]  # type: ignore[assignment]
     """
     Fires:
-        Before finishing the `cobib.commands.list.ListCommand`.
+        Before finishing the `cobib.commands.list_.ListCommand`.
 
     Arguments:
-        - `labels`: the list of labels.
+        - `cobib.commands.list_.ListCommand`: the command instance that just ran.
 
     Returns:
         Nothing.
     """
 
-    PreModifyCommand: Event = Callable[[Namespace], None]  # type: ignore[assignment]
+    PreModifyCommand: Event = Callable[["commands.ModifyCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before starting the `cobib.commands.modify.ModifyCommand`.
 
     Arguments:
-        - `largs`: the `Namespace` dictionary of command arguments.
+        - `cobib.commands.modify.ModifyCommand`: the command instance that is about to run.
 
     Returns:
-        Nothing. But the `Namespace` can be modified, affecting the command execution.
+        Nothing. But the command attributes can be modified, affecting the execution.
     """
-    PostModifyCommand: Event = Callable[[List[str], bool], None]  # type: ignore[assignment]
+    PostModifyCommand: Event = Callable[["commands.ModifyCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before finishing the `cobib.commands.modify.ModifyCommand`.
 
     Arguments:
-        - `labels`: the list of modified labels.
-        - `dry`: whether the command was run in dry-mode.
+        - `cobib.commands.modify.ModifyCommand`: the command instance that just ran.
 
     Returns:
-        Nothing.
+        Nothing. But the modified entries are still accessible before written to the database.
     """
 
-    PreOpenCommand: Event = Callable[[Namespace], None]  # type: ignore[assignment]
+    PreOpenCommand: Event = Callable[["commands.OpenCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before starting the `cobib.commands.open.OpenCommand`.
 
     Arguments:
-        - `largs`: the `Namespace` dictionary of command arguments.
+        - `cobib.commands.open.OpenCommand`: the command instance that is about to run.
 
     Returns:
-        Nothing. But the `Namespace` can be modified, affecting the command execution.
+        Nothing. But the command attributes can be modified, affecting the execution.
     """
-    PostOpenCommand: Event = Callable[[List[str]], None]  # type: ignore[assignment]
+    PostOpenCommand: Event = Callable[["commands.OpenCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before finishing the `cobib.commands.open.OpenCommand`.
 
     Arguments:
-        - `labels`: the list of opened labels.
+        - `cobib.commands.open.OpenCommand`: the command instance that just ran.
 
     Returns:
         Nothing.
     """
 
-    PreRedoCommand: Event = Callable[[Namespace], None]  # type: ignore[assignment]
+    PreRedoCommand: Event = Callable[["commands.RedoCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before starting the `cobib.commands.redo.RedoCommand`.
 
     Arguments:
-        - `largs`: the `Namespace` dictionary of command arguments.
+        - `cobib.commands.redo.RedoCommand`: the command instance that is about to run.
 
     Returns:
-        Nothing. But the `Namespace` can be modified, affecting the command execution.
-
-    Note:
-        As of right now, the `redo` command does not take any arguments, so there is nothing to
-        modify here.
+        Nothing. But the command attributes can be modified, affecting the execution.
     """
-    PostRedoCommand: Event = Callable[[Path, str], None]  # type: ignore[assignment]
+    PostRedoCommand: Event = Callable[["commands.RedoCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before finishing the `cobib.commands.redo.RedoCommand`.
 
     Arguments:
-        - `root`: the `Path` to the root directory where the database file resides.
-        - `sha`: the SHA of the redone git-commit.
+        - `cobib.commands.redo.RedoCommand`: the command instance that just ran.
 
     Returns:
         Nothing.
     """
 
-    PreSearchCommand: Event = Callable[[Namespace], None]  # type: ignore[assignment]
+    PreReviewCommand: Event = Callable[["commands.ReviewCommand"], None]  # type: ignore[assignment]
+    """
+    Fires:
+        Before starting the `cobib.commands.review.ReviewCommand`.
+        The only logic which is done prior to this event is the retrieval of the command arguments
+        from a previous review process when the `--resume` option has been specified.
+
+    Arguments:
+        - `cobib.commands.review.ReviewCommand`: the command instance that is about to run.
+
+    Returns:
+        Nothing. But the command attributes can be modified, affecting the execution.
+    """
+    PostReviewCommand: Event = Callable[["commands.ReviewCommand"], None]  # type: ignore[assignment]
+    """
+    Fires:
+        Before finishing the `cobib.commands.review.ReviewCommand`.
+
+    Arguments:
+        - `cobib.commands.review.ReviewCommand`: the command instance that just ran.
+
+    Returns:
+        Nothing.
+    """
+
+    PreSearchCommand: Event = Callable[["commands.SearchCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before starting the `cobib.commands.search.SearchCommand`.
 
     Arguments:
-        - `largs`: the `Namespace` dictionary of command arguments.
+        - `cobib.commands.search.SearchCommand`: the command instance that is about to run.
 
     Returns:
-        Nothing. But the `Namespace` can be modified, affecting the command execution.
+        Nothing. But the command attributes can be modified, affecting the execution.
     """
-    PostSearchCommand: Event = Callable[[int, List[str]], None]  # type: ignore[assignment]
+    PostSearchCommand: Event = Callable[["commands.SearchCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before finishing the `cobib.commands.search.SearchCommand`.
 
     Arguments:
-        - `hits`: the number of matches found in the database.
-        - `labels`: the list of matching labels.
+        - `cobib.commands.search.SearchCommand`: the command instance that just ran.
 
     Returns:
-        Nothing.
+        Nothing. But the search results are still accessible before being rendered for the user.
     """
 
-    PreShowCommand: Event = Callable[[Namespace], None]  # type: ignore[assignment]
+    PreShowCommand: Event = Callable[["commands.ShowCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before starting the `cobib.commands.show.ShowCommand`.
 
     Arguments:
-        - `largs`: the `Namespace` dictionary of command arguments.
+        - `cobib.commands.show.ShowCommand`: the command instance that is about to run.
 
     Returns:
-        Nothing. But the `Namespace` can be modified, affecting the command execution.
+        Nothing. But the command attributes can be modified, affecting the execution.
     """
-    PostShowCommand: Event = Callable[[str], Optional[str]]  # type: ignore[assignment]
+    PostShowCommand: Event = Callable[["commands.ShowCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before finishing the `cobib.commands.show.ShowCommand`.
 
     Arguments:
-        - `entry_str`: the formatted string-representation of the shown `Entry`.
+        - `cobib.commands.show.ShowCommand`: the command instance that just ran.
 
     Returns:
-        Optionally a new (or updated) string to represent the shown `Entry`.
-
-    Note:
-        If a registered hook returns a new string, no subsequent hooks will be run!
+        Nothing. But the string-represented entry is still accessible before being rendered.
     """
 
-    PreUndoCommand: Event = Callable[[Namespace], None]  # type: ignore[assignment]
+    PreUndoCommand: Event = Callable[["commands.UndoCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before starting the `cobib.commands.undo.UndoCommand`.
 
     Arguments:
-        - `largs`: the `Namespace` dictionary of command arguments.
+        - `cobib.commands.undo.UndoCommand`: the command instance that is about to run.
 
     Returns:
-        Nothing. But the `Namespace` can be modified, affecting the command execution.
+        Nothing. But the command attributes can be modified, affecting the execution.
     """
-    PostUndoCommand: Event = Callable[[Path, str], None]  # type: ignore[assignment]
+    PostUndoCommand: Event = Callable[["commands.UndoCommand"], None]  # type: ignore[assignment]
     """
     Fires:
         Before finishing the `cobib.commands.undo.UndoCommand`.
 
     Arguments:
-        - `root`: the `Path` to the root directory where the database file resides.
-        - `sha`: the SHA of the undone git-commit.
+        - `cobib.commands.undo.UndoCommand`: the command instance that just ran.
 
     Returns:
         Nothing.
@@ -460,7 +530,7 @@ class Event(Enum):
         Before starting `cobib.parsers.bibtex.BibtexParser.dump`.
 
     Arguments:
-        - `Entry`: the `Entry` object to be dumped in BibTeX format.
+        - `cobib.database.Entry`: the `Entry` object to be dumped in BibTeX format.
 
     Returns:
         Nothing. But the object can be modified in-place. Changes will *not* become persistent in
@@ -513,7 +583,7 @@ class Event(Enum):
         Before starting `cobib.parsers.yaml.YAMLParser.dump`.
 
     Arguments:
-        - `Entry`: the `Entry` object to be dumped in YAML format.
+        - `cobib.database.Entry`: the `Entry` object to be dumped in YAML format.
 
     Returns:
         Nothing. But the object can be modified in-place. Changes will *not* become persistent in
@@ -642,40 +712,30 @@ class Event(Enum):
         propagated to the database.
     """
 
-    PreZoteroImport: Event = Callable[  # type: ignore[assignment]
-        [str, Dict[str, str]], Optional[Tuple[str, Dict[str, str]]]
-    ]
+    PreZoteroImport: Event = Callable[["importers.ZoteroImporter"], None]  # type: ignore[assignment]
     """
     Fires:
         Before starting `cobib.importers.zotero.ZoteroImporter.fetch`.
 
     Arguments:
-        - `url`: the URL from which to fetch the Zotero library.
-        - `authentication`: the authentication dictionary header for the GET request.
+        - `cobib.importers.zotero.ZoteroImporter`: the importer instance that is about to run.
 
     Returns:
-        This can optionally return a tuple overwriting the input arguments.
-
-    Note:
-        If a registered hook returns a new tuple of arguments, no subsequent hooks will be run!
+        Nothing. But the importer attributes can be modified, affecting the execution.
     """
-
-    PostZoteroImport: Event = Callable[  # type: ignore[assignment]
-        [List["Entry"]], Optional[List["Entry"]]
-    ]
+    PostZoteroImport: Event = Callable[["importers.ZoteroImporter"], None]  # type: ignore[assignment]
     """
     Fires:
         Before finishing `cobib.importers.zotero.ZoteroImporter.fetch`.
 
     Arguments:
-        - `imported_entries`: the list of entries to be imported.
+        - `cobib.importers.zotero.ZoteroImporter`: the importer instance that is about to run.
 
     Returns:
-        This can optionally return an updated list of imported entries.
+        Nothing. But the importer attributes can be modified, affecting the execution.
 
     Note:
         - The entry labels will not have been mapped or disambiguated at this point.
-        - If a registered hook returns a new tuple of arguments, no subsequent hooks will be run!
     """
 
     PreFileDownload: Event = Callable[  # type: ignore[assignment]
@@ -714,9 +774,7 @@ class Event(Enum):
         If a registered hook returns a new path, no subsequent hooks will be run!
     """
 
-    PreGitCommit: Event = Callable[  # type: ignore[assignment]
-        [str, Optional[Dict[str, Any]]], Optional[str]
-    ]
+    PreGitCommit: Event = Callable[[str, Optional[Dict[str, Any]]], Optional[str]]  # type: ignore[assignment]
     """
     Fires:
         Before starting `cobib.commands.base_command.Command.git` (i.e. whenever an automatic
@@ -764,7 +822,7 @@ class Event(Enum):
             The same callable which ensures that we can chain multiple subscription decorators to
             subscribe the same function to multiple events.
         """
-        if self not in config.events.keys():
+        if self not in config.events:
             config.events[self] = []
         LOGGER.debug("Subscribing new hook to %s.", str(self))
         config.events[self].append(function)
@@ -785,7 +843,7 @@ class Event(Enum):
             Whatever a hook returns or `None` as a default.
         """
         LOGGER.debug("Firing %s.", str(self))
-        if self not in config.events.keys():
+        if self not in config.events:
             return None
         for hook in config.events[self]:
             res = hook(*args, **kwargs)
@@ -799,10 +857,10 @@ class Event(Enum):
         Returns:
             Whether or not all subscribers have the correct type hint.
         """
-        if self not in config.events.keys():
+        if self not in config.events:
             return True
 
-        def _compare_types(expected: Any, provided: Any) -> List[bool]:
+        def _compare_types(expected: Any, provided: Any) -> list[bool]:
             result = []
             for exp, pro in zip_longest(expected, provided):
                 try:
