@@ -3,7 +3,6 @@
 Since all commands are tested separately in their respective test files, the tests here mainly deal
 with testing the global parser arguments.
 """
-# pylint: disable=unused-argument
 
 from __future__ import annotations
 
@@ -43,7 +42,7 @@ class TestMainExecutable(CmdLineTest):
         """
         with pytest.raises(SystemExit):
             await self.run_module(monkeypatch, "main", ["cobib", "--version"])
-        # pylint: disable=import-outside-toplevel
+
         from cobib import __version__
 
         assert capsys.readouterr().out.strip() == f"coBib v{__version__}"
@@ -81,7 +80,7 @@ class TestMainExecutable(CmdLineTest):
             level: the level of the verbosity argument.
         """
         # we choose the open command as an arbitrary choice which has minimal side effects
-        args = ["cobib"] + args
+        args = ["cobib", *args]
         if verbosity_arg:
             args.insert(1, verbosity_arg)
         await self.run_module(monkeypatch, "main", args)
@@ -108,10 +107,10 @@ class TestMainExecutable(CmdLineTest):
         """
         logfile = str(Path(tempfile.gettempdir()) / "cobib_test_logging.log")
         # we choose the open command as an arbitrary choice which has minimal side effects
-        await self.run_module(monkeypatch, "main", ["cobib", "-l", logfile] + args)
+        await self.run_module(monkeypatch, "main", ["cobib", "-l", logfile, *args])
         try:
             assert isinstance(logging.getLogger().handlers[-1], logging.FileHandler)
-            assert logging.getLogger().handlers[-1].baseFilename == logfile  # type: ignore
+            assert logging.getLogger().handlers[-1].baseFilename == logfile  # type: ignore[attr-defined]
         finally:
             os.remove(logfile)
 
@@ -131,5 +130,5 @@ class TestMainExecutable(CmdLineTest):
             args: the list of values with which to monkeypatch `sys.argv`.
         """
         # we choose the open command as an arbitrary choice which has minimal side effects
-        await self.run_module(monkeypatch, "main", ["cobib", "-c", get_resource("debug.py")] + args)
+        await self.run_module(monkeypatch, "main", ["cobib", "-c", get_resource("debug.py"), *args])
         assert config.database.file == get_resource("example_literature.yaml")
